@@ -136,7 +136,6 @@ void Connection::doSetup()
             deactivate();
         }
     });
-    connect(kwinApp()->platform(), &Platform::outputsQueried, this, &Connection::updateScreens);
     handleEvent();
 }
 
@@ -529,7 +528,7 @@ void Connection::applyScreenToDevice(Device *device)
 {
 #ifndef KWIN_BUILD_TESTING
     QMutexLocker locker(&m_mutex);
-    if (!device->isTouch()) {
+    if (!device->isTouch() && !device->isTabletTool()) {
         return;
     }
 
@@ -549,7 +548,7 @@ void Connection::applyScreenToDevice(Device *device)
             }
         }
     }
-    if (!deviceOutput) {
+    if (!deviceOutput && device->isTouch()) {
         // do we have an internal screen?
         Output *internalOutput = nullptr;
         for (Output *output : outputs) {
