@@ -157,6 +157,11 @@ public:
      * for update.
      */
     QPoint pos();
+    /**
+     * Warps the mouse cursor to new @p pos.
+     * Values will be rounded to an integer
+     */
+    void setPos(const QPointF &pos);
     /**
      * Warps the mouse cursor to new @p pos.
      */
