@@ -13,7 +13,7 @@ namespace KWin
 
 MouseEvent::MouseEvent(QEvent::Type type, const QPointF &pos, Qt::MouseButton button,
                        Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers,
-                       quint32 timestamp, const QSizeF &delta, const QSizeF &deltaNonAccelerated,
+                       quint32 timestamp, const QPointF &delta, const QPointF &deltaNonAccelerated,
                        quint64 timestampMicroseconds, InputDevice *device)
     : QMouseEvent(type, pos, pos, button, buttons, modifiers)
     , m_delta(delta)
