@@ -14,7 +14,7 @@ namespace KWin
 
 static const int MSC_DAY = 86400000;
 static const int MIN_TEMPERATURE = 1000;
-static const int NEUTRAL_TEMPERATURE = 6500;
+static const int DEFAULT_DAY_TEMPERATURE = 6500;
 static const int DEFAULT_NIGHT_TEMPERATURE = 4500;
 static const int FALLBACK_SLOW_UPDATE_TIME = 1800000; /* 30 minutes */
 
