@@ -12,25 +12,40 @@
 #define KWIN_SM_H
 
 #include <QDataStream>
-#include <kwinglobals.h>
-#include <QStringList>
-#include <netwm_def.h>
 #include <QRect>
+#include <QStringList>
+
+#include <KConfigGroup>
+
+#include <kwinglobals.h>
+#include <netwm_def.h>
 
 namespace KWin
 {
 
-class X11Client;
+class X11Window;
+struct SessionInfo;
 
 class SessionManager : public QObject
 {
     Q_OBJECT
 public:
+    enum SMSavePhase {
+        SMSavePhase0, // saving global state in "phase 0"
+        SMSavePhase2, // saving window state in phase 2
+        SMSavePhase2Full, // complete saving in phase2, there was no phase 0
+    };
+
     SessionManager(QObject *parent);
     ~SessionManager() override;
 
     SessionState state() const;
 
+    void loadSubSessionInfo(const QString &name);
+    void storeSubSession(const QString &name, QSet<QByteArray> sessionIds);
+
+    SessionInfo *takeSessionInfo(X11Window *);
+
 Q_SIGNALS:
     void stateChanged();
 
@@ -47,10 +62,22 @@ public Q_SLOTS: // DBus API
 
 private:
     void setState(SessionState state);
+
+    void storeSession(const QString &sessionName, SMSavePhase phase);
+    void storeClient(KConfigGroup &cg, int num, X11Window *c);
+    void loadSessionInfo(const QString &sessionName);
+    void addSessionInfo(KConfigGroup &cg);
+
     SessionState m_sessionState = SessionState::Normal;
+
+    int m_sessionActiveClient;
+    int m_sessionDesktop;
+
+    QList<SessionInfo *> session;
 };
 
-struct SessionInfo {
+struct SessionInfo
+{
     QByteArray sessionId;
     QByteArray windowRole;
     QByteArray wmCommand;
@@ -82,13 +109,6 @@ struct SessionInfo {
     QStringList activities;
 };
 
-
-enum SMSavePhase {
-    SMSavePhase0,     // saving global state in "phase 0"
-    SMSavePhase2,     // saving window state in phase 2
-    SMSavePhase2Full, // complete saving in phase2, there was no phase 0
-};
-
 } // namespace
 
 #endif
