@@ -34,9 +34,9 @@ public:
 
 private:
     friend class PrimarySelectionDeviceManagerV1InterfacePrivate;
-    explicit PrimarySelectionSourceV1Interface(PrimarySelectionDeviceManagerV1Interface *parent, ::wl_resource *resource);
+    explicit PrimarySelectionSourceV1Interface(::wl_resource *resource);
 
-    QScopedPointer<PrimarySelectionSourceV1InterfacePrivate> d;
+    std::unique_ptr<PrimarySelectionSourceV1InterfacePrivate> d;
 };
 
 }
